pub enum CashflowVariable {
PresentValueAnnuity,
PresentValueAnnuityDue,
FutureValueAnnuity,
Payment,
FutureValueAnnuityDue,
NetPresentValue,
}Variants
PresentValueAnnuity
PresentValueAnnuityDue
FutureValueAnnuity
Payment
FutureValueAnnuityDue
NetPresentValue
Implementations
Sourceimpl CashflowVariable
impl CashflowVariable
Sourcepub fn is_present_value_annuity(&self) -> bool
pub fn is_present_value_annuity(&self) -> bool
Returns true if the variant is CashflowVariable::PresentValueAnnuity indicating that the solution was created by calculating the present value of an annuity with the payment due at the end of the month.
Sourcepub fn is_future_value_annuity(&self) -> bool
pub fn is_future_value_annuity(&self) -> bool
Returns true if the variant is CashflowVariable::FutureValueAnnuity indicating that the solution was created by calculating the future value of an annuity with the payment due at the end of the month.
Sourcepub fn is_payment(&self) -> bool
pub fn is_payment(&self) -> bool
Returns true if the variant is CashflowVariable::Payment indicating that the solution
was created in a call to payment_solution.
Sourcepub fn is_present_value_annuity_due(&self) -> bool
pub fn is_present_value_annuity_due(&self) -> bool
Returns true if the variant is CashflowVariable::PresentValueAnnuityDue indicating that the solution was created by calculating the present value of an annuity with the payment due at the beginning of the month.
Sourcepub fn is_future_value_annuity_due(&self) -> bool
pub fn is_future_value_annuity_due(&self) -> bool
Returns true if the variant is CashflowVariable::FutureValueAnnuityDue indicating that the solution was created by calculating the future value of an annuity with the payment due at the beginning of the month.
Sourcepub fn is_net_present_value(&self) -> bool
pub fn is_net_present_value(&self) -> bool
Returns true if the variant is CashflowVariable::NetPresentValue indicating that the solution was created by calculating a net present value.