nper_solution

Function nper_solution 

pub fn nper_solution<C: Into<f64> + Copy, P: Into<f64> + Copy, F: Into<f64> + Copy>(
    periodic_rate: f64,
    payment: C,
    present_value: P,
    future_value: F,
) -> NperSolution
Returns f64 for Number of Periods (NPER). Receive the number of periods required for a present value to equal a future value based on a set of payments (annuity) at an interest rate. If there is no initial present value, use 0. This is equivalent to the NPER function in Excel / Google Sheets.