Periodic rate calculations. Given an initial investment amount, a final amount, and a number of periods what does the rate per period need to be?
For most common usages, we recommend the rate_solution function to provide the best experience with debugging and additional features.
Formulas
Simple Compounding
With simple compound interest the rate is calculated with:
Or using a few more common variable names:
r is the periodic rate, though this may appear as i for interest. n is often used for the
number of periods, though it may be t for time if each period is assumed to be one year as in
continuous compounding.
Throughout this crate we use pv for present value and fv for future value. You may see these
values called P for principal in some references.
Continuous Compounding
With continuous compounding the formula is:
or:
With continuous compounding the period is assumed to be years and t (time) is often used as
the variable name. Within this crate we stick with n for the number of periods so that all of
the functions use the same variables.
Functions
- rate
- Returns the periodic rate of an investment given the number of periods along with the present and future values.
- rate_
solution - Returns the periodic rate of an investment given the number of periods along with the present and future values.